@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2003-2009 Ralf Hoffmann.
+ * Copyright (C) 2003-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -366,7 +366,9 @@ struct mytoken tokenlist[]={
   { UNMOUNTCOMMAND_WCP, "unmountcommand" },
   { FSTABFILE_WCP, "fstabfile" },
   { MTABFILE_WCP, "mtabfile" },
-  { PARTFILE_WCP, "partfile" }
+  { PARTFILE_WCP, "partfile" },
+  { REQUESTACTION_WCP, "requestaction" },
+  { WEIGHTTOACTIVE_WCP, "weighttoactive" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
