@@ -1,6 +1,6 @@
 /* volumemanagerui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009 Ralf Hoffmann.
+ * Copyright (C) 2009-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -79,7 +79,7 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
     m_lv->setDisplayFocus( true );
     m_lv->setGlobalFieldSpace( 5 );
 
-    AContainer *cont4 = m_cont2->add( new AContainer( m_win.get(), 1, 5 ), 1, 0 );
+    AContainer *cont4 = m_cont2->add( new AContainer( m_win.get(), 1, 4 ), 1, 0 );
     cont4->setBorderWidth( 0 );
     cont4->setMinSpace( 5 );
     cont4->setMaxSpace( 5 );
@@ -88,10 +88,14 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
                                                   0, 0, AContainer::CO_FIX ) );
     m_unmountb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 886 ), 1, 0, 0 ),
                                                      0, 1, AContainer::CO_FIX ) );
-    m_hideb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 887 ), 1, 0, 0 ),
+    m_hideb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix,
+                                                             0, 0,
+                                                             catalog.getLocale( 887 ),
+                                                             catalog.getLocale( 888 ),
+                                                             1, 1,
+                                                             0, 0,
+                                                             0 ),
                                                  0, 2, AContainer::CO_FIX ) );
-    m_edit_hiddenb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 888 ), 1, 0, 0 ),
-                                                        0, 3, AContainer::CO_FIX ) );
     AContainer *cont7 = cont0->add( new AContainer( m_win.get(), 2, 1 ), 0, 2 );
     cont7->setBorderWidth( 0 );
     cont7->setMinSpace( 5 );
@@ -201,9 +205,11 @@ int VolumeManagerUI::mainLoop()
                   } else if ( msg->button.button == m_unmountb ) {
                       unmountRow( m_lv->getActiveRow() );
                   } else if ( msg->button.button == m_hideb ) {
-                      hide( m_lv->getActiveRow() );
-                  } else if ( msg->button.button == m_edit_hiddenb ) {
-                      editHideList();
+                      if ( msg->button.state == 2 ) {
+                          editHideList();
+                      } else {
+                          hide( m_lv->getActiveRow() );
+                      }
                   }
                   break;
               case AG_KEYPRESSED:
