@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009 Ralf Hoffmann.
+ * Copyright (C) 2001-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -46,11 +46,14 @@ class Lister;
 class BookmarkDBProxy;
 class PopUpMenu;
 class HWVolume;
+class WaitThread;
+class TimeoutStore;
+class EventQueue;
 
 class Worker
 {
 public:
-  Worker(int argc,char **argv);
+  Worker( int argc, char **argv, int optind = -1 );
   ~Worker();
   Worker( const Worker &other );
   Worker &operator=( const Worker &other );
@@ -124,6 +127,10 @@ public:
 
     HWVolumeManager &getVolumeManager();
     void clearNewVolumesInfo();
+
+    void registerTimeout( loff_t timeout_ms );
+    void unregisterTimeout( loff_t timeout_ms );
+    void wakeupMainLoop();
  protected:
   void createMainWin();
   void setupMainWin();
@@ -162,6 +169,7 @@ public:
   int runningmode;
   static int argc;
   static char **argv;
+  static int m_optind;
   static std::string startcwd;
   time_t lasttimep;
   
@@ -229,6 +237,7 @@ public:
 
     std::list< TimedText > m_statebar_texts;
     bool getValidStatebarText( TimedText &return_text );
+    bool getNextValidStatebarText( TimedText &return_text );
     void updateStatebar();
 
     TimedText m_key_message;
@@ -236,10 +245,29 @@ public:
 
     HWVolumeManager m_volume_manager;
     void checkNewVolumes();
-    std::list< HWVolume > m_current_new_volumes;
+    std::list< HWVolume > m_known_volumes;
     TimedText m_new_volumes_infotext;
 
     void updateVolumeManagerConfig();
+    void initVolumeManagerStuff();
+
+    void queryNewVolumeAction( const std::list< HWVolume > &l );
+
+    void initWaitThread();
+    void shutdownWaitThread();
+
+    RefCount< EventQueue > m_eventqueue;
+    RefCount< TimeoutStore > m_timeouts;
+    RefCount< WaitThread > m_waitthread;
+
+    loff_t m_current_clock_update_ms;
+    void setClockUpdate( loff_t time_ms );
+
+    loff_t m_current_dbus_update_ms;
+    void setDbusUpdate( loff_t time_ms );
+
+    loff_t m_current_statebar_update_ms;
+    void setStatebarUpdate( loff_t time_ms );
 };
 
 #endif
