@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009 Ralf Hoffmann.
+ * Copyright (C) 2001-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -23,8 +23,10 @@
 #include "wconfig.h"
 #include "worker.h"
 #include <aguix/utf8.hh>
+#include "workerinitialsettings.hh"
+#include "nwc_path.hh"
 
-#define CATENTRY 900
+#define CATENTRY 909
 #define CATCOMENTRY 59
 #define CATFLAGENTRY 59
 
@@ -69,7 +71,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[13]=dupstring( "Bytes" );
   catalog[14]=dupstring( "Number of colors:" );
   catalog[15]=dupstring( "Palette" );
-  catalog[16]=dupstring( "Filelister settings" );
+  catalog[16]=dupstring( "File lister settings" );
   catalog[17]=dupstring( "Number of rows:" );
   catalog[18]=dupstring( "Number of columns:" );
   catalog[19]=dupstring( "Left list view" );
@@ -93,10 +95,10 @@ void WorkerLocale::initBuiltinLang()
   catalog[37]=dupstring( "selected directory" );
   catalog[38]=dupstring( "unselected file" );
   catalog[39]=dupstring( "selected file" );
-  catalog[40]=dupstring( "Can't save the config to %s!|Please check the worker installation!" );
+  catalog[40]=dupstring( "Can't save the configuration to %s!|Please check the worker installation!" );
   catalog[41]=dupstring( "Retry" );
   catalog[42]=dupstring( "A button named %s already uses this shortcut!|Click Okay to remove the reference to this shortcut|from the button and use it here instead" );
-  catalog[43]=dupstring( "Clockbar" );
+  catalog[43]=dupstring( "Clock bar" );
   catalog[44]=dupstring( "Requester" );
   catalog[45]=dupstring( "Choose color:" );
   catalog[46]=dupstring( "Left startup path:" );
@@ -121,9 +123,9 @@ void WorkerLocale::initBuiltinLang()
   catalog[65]=dupstring( "A hotkey named %s already uses this shortcut!|Click Okay to remove the reference to this shortcut|from the hotkey and use it here instead" );
   catalog[66]=dupstring( "Please press the key for the shortcut!" );
   catalog[67]=dupstring( "The destination directory %s doesn't exists!" );
-  catalog[68]=dupstring( "Bank nr.:" );
+  catalog[68]=dupstring( "Bank no.:" );
   catalog[69]=dupstring( "Next bank" );
-  catalog[70]=dupstring( "Prev. bank" );
+  catalog[70]=dupstring( "Prev bank" );
   catalog[71]=dupstring( "New bank" );
   catalog[72]=dupstring( "Delete bank" );
   catalog[73]=dupstring( "Copy path" );
@@ -199,7 +201,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[143]=dupstring( "remaining dirs:" );
   catalog[144]=dupstring( "" );
   catalog[145]=dupstring( "Do you really want to delete %ld files and %ld dirs recursively?" );
-  catalog[146]=dupstring( "The dir %s is not empty|Delete it recursively?" );
+  catalog[146]=dupstring( "The directory %s is not empty|Delete it recursively?" );
   catalog[147]=dupstring( "Can't remove the directory %s!" );
   catalog[148]=dupstring( "Enter new name for %s:" );
   catalog[149]=dupstring( "Rename" );
@@ -252,7 +254,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[196]=dupstring( "Set to default" );
   catalog[197]=dupstring( "" );
   catalog[198]=dupstring( "Can't open destination file %s!" );
-  catalog[199]=dupstring( "Enter dir to ignore for filetype checking:" );
+  catalog[199]=dupstring( "Enter directory to ignore for file type check:" );
   catalog[200]=dupstring( "Enter text:" );
   catalog[201]=dupstring( "Press RETURN to continue!" );
   catalog[202]=dupstring( "" );
@@ -319,16 +321,16 @@ void WorkerLocale::initBuiltinLang()
   catalog[263]=dupstring( "User8 action" );
   catalog[264]=dupstring( "User9 action" );
   catalog[265]=dupstring( "Select file" );
-  catalog[266]=dupstring( "Select the file of the file type you wan't to create:" );
+  catalog[266]=dupstring( "Select the file of the file type you want to create:" );
   catalog[267]=dupstring( "Please select three existing files for automatic creation!" );
   catalog[268]=dupstring( "Select entries" );
   catalog[269]=dupstring( "Deselect entries" );
   catalog[270]=dupstring( "Enter the pattern the matching entries will be selected for:" );
   catalog[271]=dupstring( "Enter the pattern the matching entries will be deselected for:" );
-  catalog[272]=dupstring( "Wan't to handle dirs instead of files? Enter \"/\" as first character!" );
-  catalog[273]=dupstring( "Use this dir" );
+  catalog[272]=dupstring( "Want to handle directories instead of files? Enter \"/\" as first character!" );
+  catalog[273]=dupstring( "Use this directory" );
   catalog[274]=dupstring( "Delete link" );
-  catalog[275]=dupstring( "There is already a symlink named %s, which points to a dir|You can use it so the destination dir is used|or delete the link to create a real directory" );
+  catalog[275]=dupstring( "There is already a symlink named %s, which points to a directory|You can use it so the destination directory is used|or delete the link to create a real directory" );
   catalog[276]=dupstring( "Failed to remove this file.|Please enter new name!" );
   catalog[277]=dupstring( "Delete file" );
   catalog[278]=dupstring( "There is already a link named %s" );
@@ -341,9 +343,9 @@ void WorkerLocale::initBuiltinLang()
   catalog[285]=dupstring( "copied dirs" );
   catalog[286]=dupstring( "Failed to remove the file %s!" );
   catalog[287]=dupstring( "Delete all" );
-  catalog[288]=dupstring( "Delete no non empty dirs" );
-  catalog[289]=dupstring( "The dir %s is not completely deleted!" );
-  catalog[290]=dupstring( "Enter dir you want to cd to:" );
+  catalog[288]=dupstring( "Delete only empty dirs" );
+  catalog[289]=dupstring( "The directory %s is not completely deleted!" );
+  catalog[290]=dupstring( "Enter directory you want to cd to:" );
   catalog[291]=dupstring( "Can't remove %s!" );
   catalog[292]=dupstring( "No options available" );
   catalog[293]=dupstring( "Configure \"%s\"" );
@@ -354,7 +356,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[298]=dupstring( "Follow symlinks" );
   catalog[299]=dupstring( "Move" );
   catalog[300]=dupstring( "Rename" );
-  catalog[301]=dupstring( "Same dir" );
+  catalog[301]=dupstring( "Same directory" );
   catalog[302]=dupstring( "Request destination" );
   catalog[303]=dupstring( "Overwrite mode" );
   catalog[304]=dupstring( "request" );
@@ -373,9 +375,9 @@ void WorkerLocale::initBuiltinLang()
   catalog[317]=dupstring( "Action" );
   catalog[318]=dupstring( "enter active entry" );
   catalog[319]=dupstring( "enter active entry on other side" );
-  catalog[320]=dupstring( "special dir" );
+  catalog[320]=dupstring( "special directory" );
   catalog[321]=dupstring( "request directory" );
-  catalog[322]=dupstring( "special dir:" );
+  catalog[322]=dupstring( "special directory:" );
   catalog[323]=dupstring( "Side to edit" );
   catalog[324]=dupstring( "current side" );
   catalog[325]=dupstring( "other side" );
@@ -407,9 +409,9 @@ void WorkerLocale::initBuiltinLang()
   catalog[351]=dupstring( "request" );
   catalog[352]=dupstring( "quick" );
   catalog[353]=dupstring( "Dir positions:" );
-  catalog[354]=dupstring( "Dirs first" );
-  catalog[355]=dupstring( "Dirs last" );
-  catalog[356]=dupstring( "Dirs mixed" );
+  catalog[354]=dupstring( "Directories first" );
+  catalog[355]=dupstring( "Directories last" );
+  catalog[356]=dupstring( "Directories mixed" );
   catalog[357]=dupstring( "Show hidden entries" );
   catalog[358]=dupstring( "Don't use" );
   catalog[359]=dupstring( "Error while writing %s !" );
@@ -420,7 +422,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[364]=dupstring( "" );
   catalog[365]=dupstring( "Sorry, there is no such font!" );
   catalog[366]=dupstring( "" );
-  catalog[367]=dupstring( "The file %s isn't a worker config file!|Using default config" );
+  catalog[367]=dupstring( "The file %s isn't a worker configuration file!|Using default configuration..." );
   catalog[368]=dupstring( "Clock bar settings" );
   catalog[369]=dupstring( "Clock bar mode:" );
   catalog[370]=dupstring( "Show current time and free RAM/Swap (on GNU/Linux)" );
@@ -437,7 +439,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[381]=dupstring( "Enter own font (with X name)" );
   catalog[382]=dupstring( "Font example" );
   catalog[383]=dupstring( "X font name:" );
-  catalog[384]=dupstring( "The configuration file is from a newer Worker version and cannot be loaded!|Please update atleast to version %d.%d.%d.|I will continue with the default config." );
+  catalog[384]=dupstring( "The configuration file is from a newer Worker version and cannot be loaded!|Please update at least to version %d.%d.%d.|I will continue with the default configuration." );
   catalog[385]=dupstring( "Reset directory sizes" );
   catalog[386]=dupstring( "Use <DIR> for unknown dir sizes" );
   catalog[387]=dupstring( "Activate shortkey" );
@@ -452,21 +454,21 @@ void WorkerLocale::initBuiltinLang()
   catalog[396]=dupstring( "Import/Export" );
   catalog[397]=dupstring( "Import" );
   catalog[398]=dupstring( "Export" );
-  catalog[399]=dupstring( "Changes made here only affect the exported config|not your real configuration!" );
+  catalog[399]=dupstring( "Changes made here only affect the exported configuration|not your real configuration!" );
   catalog[400]=dupstring( "File %s isn't a valid worker export file!" );
   catalog[401]=dupstring( "configure buttons to export" );
   catalog[402]=dupstring( "configure hotkeys to export" );
   catalog[403]=dupstring( "configure file types to export" );
-  catalog[404]=dupstring( "Filename:" );
+  catalog[404]=dupstring( "File name:" );
   catalog[405]=dupstring( "" );
   catalog[406]=dupstring( "Please select or enter file to export to:" );
   catalog[407]=dupstring( "Please mark which elements you want to export|and enter the filename!" );
-  catalog[408]=dupstring( "%s is a dir, please enter another name" );
+  catalog[408]=dupstring( "%s is a directory, please enter another name" );
   catalog[409]=dupstring( "%s already exists, overwrite?" );
   catalog[410]=dupstring( "Export to %s finished." );
   catalog[411]=dupstring( "Can't open %s for writing, please select another file" );
   catalog[412]=dupstring( "%s isn't a file!" );
-  catalog[413]=dupstring( "Export file is from a newer worker version!|Update atleast to version %d.%d.%d to use it." );
+  catalog[413]=dupstring( "Export file is from a newer worker version!|Update at least to version %d.%d.%d to use it." );
   catalog[414]=dupstring( "The configuration contains %d button bank(s), %d hotkey(s) and %d file type(s).|You can now change these parts before importing them." );
   catalog[415]=dupstring( "Please enter the file name to import from." );
   catalog[416]=dupstring( "You can change the import configuration before|the selected parts will be imported." );
@@ -482,10 +484,10 @@ void WorkerLocale::initBuiltinLang()
   catalog[426]=dupstring( "Use shortkey for new element" );
   catalog[427]=dupstring( "Use original" );
   catalog[428]=dupstring( "Use new" );
-  catalog[429]=dupstring( "The import configuration contains the special filetype %s|which would overwrite the original type %s!|Which one do you want to use?" );
+  catalog[429]=dupstring( "The import configuration contains the special file type %s|which would overwrite the original type %s!|Which one do you want to use?" );
   catalog[430]=dupstring( "Import successful" );
   catalog[431]=dupstring( "Never use shortkey for new element" );
-  catalog[432]=dupstring( "Filetype sort" );
+  catalog[432]=dupstring( "File type sort" );
   catalog[433]=dupstring( "Owner sort" );
   catalog[434]=dupstring( "Keep file types" );
   catalog[435]=dupstring( "Run in background" );
@@ -542,7 +544,7 @@ numerical value. So ( \"5\" > \"06\" ) is true while ( 5 > \"06\" ) is false!" )
   catalog[484]=dupstring( "if debug: Result of %s is %d" );
   catalog[485]=dupstring( "push debug: pushing %s at stack %d" );
   catalog[486]=dupstring( "settings" );
-  catalog[487]=dupstring( "Choose \"Recursive\" to collect all files recursively (for selected dirs)|  This can only be changed as the very first command!|Choose \"With quotes\" if you wan't to use filenames in quotes when replacing flags|\
+  catalog[487]=dupstring( "Choose \"Recursive\" to collect all files recursively (for selected dirs)|  This can only be changed as the very first command!|Choose \"With quotes\" if you want to use file names in quotes when replacing flags|\
   This can be changed by any time" );
   catalog[488]=dupstring( "change user window" );
   catalog[489]=dupstring( "Here you can change the window to show some information to the user.|You can change the progress bar by any string which can contain flags and|you can also use the output\
@@ -580,12 +582,12 @@ bar and this string can contain \\||for a new line (as many as you want). Of cou
   catalog[519]=dupstring( "Can't copy|  %s|to|  %s|Can't get symlink destination!|Error:%s" );
   catalog[520]=dupstring( "Can't copy|  %s|because it's a special file and I can't handle it yet!" );
   catalog[521]=dupstring( "Enter the image viewing program.|This program has to accept 7 arguments: the first 4 are: x, y, width height.|The 5th is the hex number of the window.|\
-Then the filename follows and the last argument is the the background color in the X11 format \"rgb:rr/gg/bb\"." );
+Then the file name follows and the last argument is the background color in the X11 format \"rgb:rr/gg/bb\"." );
   catalog[522]=dupstring( "Enter command and additional arguments:|This string will be executed in a shell but not all shell features \
 are allowed!|You can use \"&&\", \"\\|\\|\", \"\\|\", \";\" and \"&\"  (all as a single word) just as in a shell and redirections|\
 can also be used (also as single word, so e.g. 2>/dev/null have to be 2> /dev/null), but|\
 all other stuff is not allowed!|\
-You have to protect special characters in filenames with a backslash or quote them correctly.|\
+You have to protect special characters in file names with a backslash or quote them correctly.|\
 The default value here is the active entry and it's already correctly protected!" );
   catalog[523]=dupstring( "Directory cache list" );
   catalog[524]=dupstring( "Select or enter a directory:" );
@@ -603,7 +605,7 @@ The default value here is the active entry and it's already correctly protected!
   catalog[536]=dupstring( "I didn't restore the SUID/SGUID bit for the file|%s|because chown to old owner failed (probably you are not|the owner or not root)." );
   catalog[537]=dupstring( "Ignore further warnings" );
   catalog[538]=dupstring( "You changed the configuration!|Do you really want to discard your changes?" );
-  catalog[539]=dupstring( "Error while reading configuration!|The following error occurred in line %d:|%s|I will continue with the partly read config." );
+  catalog[539]=dupstring( "Error while reading configuration!|The following error occurred in line %d:|%s|I will continue with the partly read configuration." );
   catalog[540]=dupstring( "configure buttons to import" );
   catalog[541]=dupstring( "configure hotkeys to import" );
   catalog[542]=dupstring( "configure file types to import" );
@@ -645,7 +647,7 @@ The default value here is the active entry and it's already correctly protected!
 wildcards:| * for matching any string| ? for matching a single character|\
  [...] for matching a character class|See the shell manual for more information.||\
 You can also use basic regular expressions, some examples follow:| .* for matching any string|\
- \\+ matches one or more occurences| \\? matches zero or one occurence|\
+ \\+ matches one or more occurrences| \\? matches zero or one occurrence|\
  ^ matches the beginning of the line| $ matches the end| \\( and \\) can be used for sub\
  expressions| \\\\\\| matches one of the sub expressions|For more information see the regular \
 expression manual (man 7 regex)" );
@@ -755,7 +757,7 @@ if you have the ssh_askpass tool. Do you really want to continue?" );
   catalog[662]=dupstring( "Select method:" );
   catalog[663]=dupstring( "Normal (click toggles select state)" );
   catalog[664]=dupstring( "Alternative (click selects element and deselects all other)" );
-  catalog[665]=dupstring( "This version of Worker can't read your configuration from a Worker 1.x version.|If you still want to use it you should temporary install Worker 2.11.1 or older|which can import your config." );
+  catalog[665]=dupstring( "This version of Worker can't read your configuration from a Worker 1.x version.|If you still want to use it you should temporary install Worker 2.11.1 or older|which can import your configuration." );
   catalog[666]=dupstring( "Do you want to cancel the delete operation?" );
   catalog[667]=dupstring( "Abort deletion" );
   catalog[668]=dupstring( "Continue deletion" );
@@ -776,7 +778,7 @@ if you have the ssh_askpass tool. Do you really want to continue?" );
   catalog[683]=dupstring( "Create new file types or modify existing types.|File types are determined by the file name, the file content or other details.|The file type tests for child types are only checked if the tests of the parent type applies to|the actual file. This way child types need only to test specialised details for a certain file type." );
   catalog[684]=dupstring( "Add all directories to the list in which files should not be checked by content. For example this|can be useful if access to files in this directory would be very slow or generally unwanted." );
   catalog[685]=dupstring( "Hotkeys can be used for commands which are only started by a key press and not by using the mouse.|Basically they are buttons without a graphical representation." );
-  catalog[686]=dupstring( "The expert configuration contains advanced options. The unexperienced Worker user|normally don't need to change these options. Select a sub category for more information|about it." );
+  catalog[686]=dupstring( "The expert configuration contains advanced options. The inexperienced Worker user|normally don't need to change these options. Select a sub category for more information|about it." );
   catalog[687]=dupstring( "The terminal program entered here is used if external programs should be started|in an own terminal. The default is the \"xterm\" terminal program available in almost every|X11 environment but you can enter your favorite terminal program with its options as long as|it can execute a given program." );
   catalog[688]=dupstring( "Worker keeps already read directories in a cache. Information about the selected|entries and their file type is also stored. You can enter any limit of different directories|to be stored inside the cache but of course a larger cache needs more memory.|If you want to disable this feature completely, set the limit to 1." );
   catalog[689]=dupstring( "The information shown in the clock bar can be configured." );
@@ -822,7 +824,7 @@ match any font." );
   catalog[720]=dupstring( "Input is valid." );
   catalog[721]=dupstring( "Input is NOT valid!" );
   catalog[722]=dupstring( "Start directory:" );
-  catalog[723]=dupstring( "Search results will be used for further searchs!" );
+  catalog[723]=dupstring( "Search results will be used for further searches!" );
   catalog[724]=dupstring( "File name:" );
   catalog[725]=dupstring( "Case sensitive" );
   catalog[726]=dupstring( "Match content:" );
@@ -891,7 +893,7 @@ match any font." );
   catalog[789]=dupstring( "Quit Worker" );
   catalog[790]=dupstring( "Search:" );
   catalog[791]=dupstring( "Text view color for selection" );
-  catalog[792]=dupstring( "Same filesystem only" );
+  catalog[792]=dupstring( "Same file system only" );
   catalog[793]=dupstring( "Filter:" );
   catalog[794]=dupstring( "Show all" );
   catalog[795]=dupstring( "Libmagic pattern:" );
@@ -928,7 +930,7 @@ match any font." );
   catalog[826]=dupstring( "List view colors for labeled entries:" );
   catalog[827]=dupstring( "Add" );
   catalog[828]=dupstring( "Remove" );
-  catalog[829]=dupstring( "Select label to set ot remove on active entry:" );
+  catalog[829]=dupstring( "Select label to set or remove on active entry:" );
   catalog[830]=dupstring( "Ask for label at runtime" );
   catalog[831]=dupstring( "Choose label:" );
   catalog[832]=dupstring( "Bookmark/Label colors" );
@@ -999,6 +1001,15 @@ match any font." );
   catalog[897]=dupstring( "Available flags" );
   catalog[898]=dupstring( "Command used if empty: %s" );
   catalog[899]=dupstring( "File used if empty: %s" );
+  catalog[900]=dupstring( "The following new devices are available:" );
+  catalog[901]=dupstring( "Mount and CD" );
+  catalog[902]=dupstring( "Mount" );
+  catalog[903]=dupstring( "Open volume manager" );
+  catalog[904]=dupstring( "Do nothing" );
+  catalog[905]=dupstring( "Mount failed: %s" );
+  catalog[906]=dupstring( "Ask what to do with new devices" );
+  catalog[907]=dupstring( "Permission sort" );
+  catalog[908]=dupstring( "Set weight relative to active side" );
 
 //  catalog[]=dupstring( "" );
   
@@ -1021,8 +1032,8 @@ match any font." );
   catalogcom[16]=dupstring( "invert selection" );
   catalogcom[17]=dupstring( "go to parent dir" );
   catalogcom[18]=dupstring( "go to dir" );
-  catalogcom[19]=dupstring( "Change ListView settings" );
-  catalogcom[20]=dupstring( "switch to other listview" );
+  catalogcom[19]=dupstring( "Change list view settings" );
+  catalogcom[20]=dupstring( "switch to other list view" );
   catalogcom[21]=dupstring( "pattern select" );
   catalogcom[22]=dupstring( "pattern unselect" );
   catalogcom[23]=dupstring( "path to other side" );
@@ -1032,7 +1043,7 @@ match any font." );
   catalogcom[27]=dupstring( "Make dir" );
   catalogcom[28]=dupstring( "own command" );
   catalogcom[29]=dupstring( "rename" );
-  catalogcom[30]=dupstring( "dirsize" );
+  catalogcom[30]=dupstring( "directory size" );
   catalogcom[31]=dupstring( "simulate doubleclick" );
   catalogcom[32]=dupstring( "start prog" );
   catalogcom[33]=dupstring( "search entry" );
@@ -1041,8 +1052,8 @@ match any font." );
   catalogcom[36]=dupstring( "create symlink" );
   catalogcom[37]=dupstring( "change symlink" );
   catalogcom[38]=dupstring( "change permissions" );
-  catalogcom[39]=dupstring( "toggle listviewmode" );
-  catalogcom[40]=dupstring( "set sortmode" );
+  catalogcom[39]=dupstring( "toggle list view mode" );
+  catalogcom[40]=dupstring( "set sort mode" );
   catalogcom[41]=dupstring( "set filter" );
   catalogcom[42]=dupstring( "activate shortkey from list" );
   catalogcom[43]=dupstring( "change owner" );
@@ -1062,7 +1073,7 @@ match any font." );
   catalogcom[57]=dupstring( "Change layout" );
   catalogcom[58]=dupstring( "Volume manager" );
   
-  catalogflag[0]=dupstring( "Stringrequester" );
+  catalogflag[0]=dupstring( "String requester" );
   catalogflag[1]=dupstring( "path" );
   catalogflag[2]=dupstring( "other path" );
   catalogflag[3]=dupstring( "left path" );
@@ -1105,11 +1116,11 @@ match any font." );
   catalogflag[40]=dupstring( "true when stack is empty" );
   catalogflag[41]=dupstring( "size of stack" );
   catalogflag[42]=dupstring( "last error (0 means no error)" );
-  catalogflag[43]=dupstring( "true when filelist is empty (no more {f})" );
+  catalogflag[43]=dupstring( "true when file list is empty (no more {f})" );
   catalogflag[44]=dupstring( "always true" );
   catalogflag[45]=dupstring( "always false" );
   catalogflag[46]=dupstring( "string (flags from own command can be used)" );
-  catalogflag[47]=dupstring( "replaces with returnvalue of the command inside the brace (flags can be used)" );
+  catalogflag[47]=dupstring( "replaces with return value of the command inside the brace (flags can be used)" );
   catalogflag[48]=dupstring( "replaces with output (first line) of the command inside the brace (flags can be used)" );
   catalogflag[49]=dupstring( "replaces with the size of given stack (default 0)" );
   catalogflag[50]=dupstring( "replaces with value of the given env-variable" );
@@ -1134,9 +1145,8 @@ WorkerLocale::~WorkerLocale()
 int WorkerLocale::openCatFile(Datei*file,const char *name,const char *ext)
 {
   bool ok=false;
-  int len;
   std::string mainstr;
-  const char *home=wconfig->getHome();
+  std::string home = WorkerInitialSettings::getInstance().getConfigBaseDir();
   if ( Worker::getDataDir().length() > 0 ) {
     mainstr = Worker::getDataDir();
     mainstr += "/catalogs/";
@@ -1155,8 +1165,7 @@ int WorkerLocale::openCatFile(Datei*file,const char *name,const char *ext)
     if ( file->open( mainstr.c_str(), "r" ) == 0 ) ok = true;
   }
   if(ok==false) {
-    len=strlen(home);
-    if(len<1) return 1;
+    if ( home.length() < 1 ) return 1;
     mainstr = home;
     mainstr += "/catalogs/";
     mainstr += name;
